<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Cleanead
 */

if ( ! function_exists('cleanead_header_title') ) :
/**
 |------------------------------------------------------------------------------
 | Logo Section
 |------------------------------------------------------------------------------
 */
	function cleanead_header_title() {

		$output = '';
		$description = get_bloginfo( 'description', 'display' );

		if ( function_exists( 'has_custom_logo' ) && has_custom_logo() ) {
			$output = sprintf( '<h1 class="site-title" itemprop="headline">%s</h1>' , get_custom_logo() ); ?>
		<?php
		} else {
			if ( is_front_page() || is_home() ) { ?>
				<?php $output = sprintf('<h1 class="site-title"><a href="%s" title="'. $description .'" rel="home"> %s </a></h1><h2 class="site-description">'. $description .'</h2>', esc_url(home_url('/')), get_bloginfo('name')); ?>
			<?php
			} else {
			?>
				<?php $output = sprintf('<h2 class="site-title"><a href="%s" title="'. $description .'" rel="home">%s</a></h2><h3 class="site-description">'. $description .'</h3>', esc_url(home_url('/')), get_bloginfo('name')); ?>
			<?php
			}
		}

	echo $output;
	}
endif;

if ( ! function_exists( 'cleanead_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function cleanead_posted_on() {

	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%3$s">%4$s</time>';
		//$time_string = '<time class="entry-date published" datetime="%3$s">%4$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = sprintf(
		esc_html_x( '%s', 'post date', 'cleanead' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);

	$byline = sprintf(
		esc_html_x( '%s', 'post author', 'cleanead' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<span class="byline"> ' . $byline . '</span>';	
	echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.
	/* translators: used between list items, there is a space after the comma */
	$categories_list = get_the_category_list( esc_html__( ', ', 'cleanead' ) );
	if ( $categories_list && cleanead_categorized_blog() ) {
		printf( '<span class="cat-links">' . esc_html__( '%1$s', 'cleanead' ) . '</span>', $categories_list ); // WPCS: XSS OK.
	}

	$tags_list = get_the_tag_list( '', __( ', ', 'cleanead' ) );
	if ( $tags_list &&  !isset($meta_options['tag']) ) {
		printf( '<span class="tags-links">' . __( '%1$s&nbsp;', 'cleanead' ) . '</span>', $tags_list );
	}

	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'cleanead' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<span class="edit-link">',
		'</span>'
	);

}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function cleanead_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'cleanead_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'cleanead_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so cleanead_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so cleanead_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in cleanead_categorized_blog.
 */
function cleanead_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'cleanead_categories' );
}
add_action( 'edit_category', 'cleanead_category_transient_flusher' );
add_action( 'save_post',     'cleanead_category_transient_flusher' );

if ( ! function_exists( 'cleanead_the_posts_navigation' ) ) :
/**
 |------------------------------------------------------------------------------
 | Display navigation to next/previous set of posts when applicable.
 |------------------------------------------------------------------------------
 |
 | @todo Remove this function when WordPress 4.3 is released.
 |
 */
function cleanead_the_posts_navigation() {
	
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}
	
	//$nav_style = get_theme_mod ('cleanead_general_pagination_mode', 'default');
	$theme_options = cleanead_theme_options();
	$nav_style = $theme_options['paging'];
	
	if ( $nav_style == 'pageing-numberal') {
		// Previous/next page navigation.
		the_posts_pagination( array(
			'prev_text'          => __( '<i class="fa fa-chevron-left"></i>', 'cleanead' ),
			'next_text'          => __( '<i class="fa fa-chevron-right"></i>', 'cleanead' ),
			'before_page_number' => '<span class="meta-nav screen-reader-text">' . __( 'Page', 'cleanead' ) . ' </span>',
		) );

	} else {
		
	?>
	<nav class="paging-navigation clearfix" role="navigation">
		<span class="screen-reader-text"><?php _e( 'Posts navigation', 'cleanead' ); ?></span>
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( __( 'Older posts', 'cleanead' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts', 'cleanead' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
	
	
	};
}
endif;

if ( ! function_exists( 'cleanead_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 */
function cleanead_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<nav class="navigation post-navigation clearfix" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'cleanead' ); ?></h1>
		<div class="nav-links">
			<?php
				previous_post_link( '<div class="nav-previous">%link</div>', _x( '%title', 'Previous post link', 'cleanead' ) );
				next_post_link(     '<div class="nav-next">%link</div>',     _x( '%title', 'Next post link',     'cleanead' ) );
			?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;